<div class="panel panel-default">
    <div class="panel-heading">
        Edit Source Server Settings
        <div class="btn-toolbar pull-right">
            <div class="btn-group">
                <div (click)="save()" class="btn btn-default btn-sm">Save</div>
                <div (click)="loader.load()" class="btn btn-default btn-sm">
                    Reset
                </div>
            </div>
        </div>
    </div>
    <div class="panel-body">
        <div class="form-group">
            <label for="appHost">Source Server Host</label>
            <input
                [(ngModel)]="item.appHost"
                class="form-control"
                id="appHost"
                required
                type="text"
            />
        </div>
        <div class="form-group">
            <label for="appOracleUsername">Oracle Username</label>
            <input
                [(ngModel)]="item.appOracleUsername"
                class="form-control"
                id="appOracleUsername"
                required
                type="text"
            />
        </div>
        <div class="form-group">
            <label for="appOraclePassword">Oracle Password</label>
            <input
                [(ngModel)]="item.appOraclePassword"
                class="form-control"
                id="appOraclePassword"
                required
                type="password"
            />
        </div>
        <div class="form-group">
            <button
                (click)="item.enabled = !item.enabled"
                [class.active]="item.enabled"
                [class.btn-success]="item.enabled"
                [class.btn-warning]="!item.enabled"
                class="form-control btn"
                type="button"
            >
                {{ item.enabled ? "Enabled" : "Disabled" }}
            </button>
        </div>
    </div>
</div>
